@@ -210,10 +210,12 @@ class binary_eda_plot:
         results = pd.concat([a, b, c, d, e, f, g], axis=1)
 
         results.index = results.index.map(str)
+
+        return results
         
     def plot_discrete(self, col, ax):
 
-        self.gen_plot_data(col)
+        results = self.gen_plot_data(col)
 
 
         
